@@ -11,7 +11,7 @@
 
 raise "sorry, 1.8 was last decade" unless RUBY_VERSION >= '1.9'
 
-gem 'kramdown', '~> 1.10.0'
+gem 'kramdown', '~> 1.11.0'
 require 'kramdown'
 my_span_elements =  %w{list figure xref eref iref cref spanx vspace}
 Kramdown::Parser::Html::Constants::HTML_SPAN_ELEMENTS.concat my_span_elements
@@ -549,7 +549,7 @@ module Kramdown
       end
 
       def convert_smart_quote(el, indent, opts)
-        entity_to_str(::Kramdown::Utils::Entities.entity(el.value.to_s))
+        entity_to_str(smart_quote_entity(el))
       end
 
       def convert_math(el, indent, opts) # XXX: This is wrong
